@@ -14,7 +14,18 @@
 #' words that don't conflict with others, like "g" for "ghost" because there's 
 #' no other animal that starts with "g".
 #' @param type (character) One of message (default), warning, or string 
-#' (returns string)
+#' (returns string). If multiple colors are supplied to \code{what_color} or 
+#' \code{by_color}, type cannot be warning. (This is a limitation of the \href{https://github.com/aedobbyn/multicolor}{multicolor} packcage :/.)
+#' @param what_color (character or crayon function) One or more 
+#' \href{https://github.com/r-lib/crayon#256-colors}{\code{crayon}}-suported text color(s) 
+#' or \href{https://github.com/r-lib/crayon#styles}{\code{crayon style function}} to color
+#'  \code{what}. You might try \code{colors()} or \code{?rgb} for ideas.
+#' Use "rainbow" for c("red", "orange", "yellow", "green", "blue", "purple").
+#' @param by_color (character or crayon function) One or more 
+#' \href{https://github.com/r-lib/crayon#256-colors}{\code{crayon}}-suported text color(s)
+#' or \href{https://github.com/r-lib/crayon#styles}{\code{crayon style function}} to color
+#'  \code{who}.
+#'  Use "rainbow" for c("red", "orange", "yellow", "green", "blue", "purple").
 #' @param length (integer) Length of longcat. Ignored if other animals used.
 #' @param fortune An integer specifying the row number of fortunes.data. 
 #' Alternatively which can be a character and grep is used to try to find a 
@@ -53,8 +64,19 @@
 #' @examples
 #' say()
 #' say("what")
+#' say("meow", "cat", what_color = "blue")
 #' say('time')
-#' say('time', "poop")
+#' say('time', "poop", by_color = "cyan", what_color = "pink")
+#' 
+#' library(jsonlite)
+#' say("arresteddevelopment",
+#'     by = "hypnotoad",
+#'     what_color = c("royalblue1", "tomato2"),
+#'     by_color = c("rainbow", "rainbow"))
+#' say("simpsons",
+#'     what_color = crayon::cyan$bgMagenta,
+#'     by_color = c("salmon1", "springgreen"))
+#'     
 #' say("who you callin chicken", "chicken")
 #' say("ain't that some shit", "poop")
 #' say("icanhazpdf?", "cat")
@@ -101,15 +123,26 @@
 #' # Clippy
 #' say(fortune=59, by="clippy")
 
-say <- function(what="Hello world!", by="cat", type="message", length=18, 
-                fortune=NULL, ...) {
+say <- function(what="Hello world!", by="cat", 
+                type="message", 
+                what_color=NULL, by_color=NULL,  
+                length=18, fortune=NULL, ...) {
 
   if (length(what) > 1) {
     stop("what has to be of length 1", call. = FALSE)
   }
-
+  
+  if (crayon::has_color() == FALSE) {
+    message("Colors cannot be applied in this environment :( Try using a terminal or RStudio.")
+    what_color <- NULL
+    by_color <- NULL
+  } else {
+    what_color <- check_color(what_color)
+    by_color <- check_color(by_color)
+  }
+  
   if (what == "catfact") {
-    check4jsonlite()
+    check4pkg("jsonlite")
     what <- 
       jsonlite::fromJSON(
         'https://catfact.ninja/fact')$fact
@@ -129,7 +162,7 @@ say <- function(what="Hello world!", by="cat", type="message", length=18,
     what <- gsub("<x>", "\n", paste(as.character(what), collapse = "\n "))
   }
 
-  if (by == "hypnotoad") {
+  if (by == "hypnotoad" && what == "Hello world!") {
     what <- "All Glory to the HYPNO TOAD!"
   }
   
@@ -138,14 +171,66 @@ say <- function(what="Hello world!", by="cat", type="message", length=18,
   }  
   
   if ( what %in% c("arresteddevelopment", "doctorwho", "dexter", "futurama", "holygrail", "simpsons", "starwars", "loremipsum")) {
-    check4jsonlite()
+    check4pkg("jsonlite")
     what <- 
       jsonlite::fromJSON(
         paste0('http://api.chrisvalleskey.com/fillerama/get.php?count=1&format=json&show=', what))$db$quote
   }
-
+  
+  what_pos_start <- 
+    regexpr('%s', who)[1] - 1
+  
+  what_pos_end <- what_pos_start + 3
+  
+  color_text <- function(txt, c) {
+    if (is.null(c)) {
+      out <- txt
+    } else if (!is.null(c) && inherits(c, "crayon")) {
+      out <- c(txt)
+    } else if (!is.null(c) && is.character(c)) {
+      if (length(c) <= 1) {
+        c <- crayon::make_style(c)
+        out <- c(txt)
+      } else if (length(c) >= 1) {
+        out <- multicolor::multi_color(txt, c,
+                                       type = "string")
+      }
+    }
+    return(out)
+  }
+  
+  # TODO: when multicolor doesn't color every character individually, this should be possible
+  # and we can get rid of what_pos_start and what_pos_end
+  # what <- color_text(what, what_color)
+  # who <- color_text(who, by_color)
+  # out <- sprintf(who, what)
+  
+  # switch(type,
+  #        message = message(sprintf(who, what)),
+  #        warning = warning(sprintf(who, what)),
+  #        string = sprintf(who, what))
+  
+  out <- paste0(color_text(substr(who, 1, what_pos_start),
+                           by_color),
+                color_text(what,
+                           what_color),
+                color_text(substr(who, what_pos_end, nchar(who)),
+                           by_color))
+  
+  if (type == "warning") {
+    if (nchar(out) < 100) {
+      wl <- 100
+    } else if (nchar(out) > 8170) {
+      wl <- 8170
+    } else {
+      wl <- nchar(out) + 1
+    }
+    warn_op <- options(warning.length = wl)
+    on.exit(options(warn_op))
+  }
+  
   switch(type,
-         message = message(sprintf(who, what)),
-         warning = warning(sprintf(who, what)),
-         string = sprintf(who, what))
+         message = message(out),
+         warning = warning(out),
+         string = out)
 }
